asr.test.test\_database\_fromtree
=================================

.. automodule:: asr.test.test_database_fromtree

   
   
   .. rubric:: Functions

   
   .. autofunction:: folder_tree
   .. autofunction:: make_tree
   .. autofunction:: test_database_fromtree_raises_when_missing_uids
   .. autofunction:: test_database_fromtree_totree
   .. autofunction:: test_database_fromtree_works_without_write_permission
   
   

   
   
   

   
   
   